@@ -6,8 +6,6 @@ import sys
 import click
 from playhouse.db_url import connect
 
-from peewee_migrate.compat import string_types
-
 
 VERBOSE = ['WARNING', 'INFO', 'DEBUG', 'NOTSET']
 CLEAN_RE = re.compile(r'\s+$', re.M)
@@ -16,7 +14,6 @@ CLEAN_RE = re.compile(r'\s+$', re.M)
 def get_router(directory, database, verbose=0):
     """Load and initialize a router."""
     from peewee_migrate import LOGGER
-    from peewee_migrate.compat import exec_in
     from peewee_migrate.router import Router
 
     logging_level = VERBOSE[verbose]
@@ -25,7 +22,8 @@ def get_router(directory, database, verbose=0):
     ignore = schema = None
     try:
         with open(os.path.join(directory, 'conf.py')) as cfg:
-            exec_in(cfg.read(), config, config)
+            code = compile(cfg.read(), '<string>', 'exec', dont_inherit=True)
+            exec(code, config, config)
             database = config.get('DATABASE', database)
             ignore = config.get('IGNORE', ignore)
             schema = config.get('SCHEMA', schema)
@@ -34,7 +32,7 @@ def get_router(directory, database, verbose=0):
     except IOError:
         pass
 
-    if isinstance(database, string_types):
+    if isinstance(database, str):
         database = connect(database)
 
     LOGGER.setLevel(logging_level)
@@ -72,7 +70,7 @@ def migrate(name=None, database=None, directory=None, verbose=None, fake=False):
 @click.option('--auto', default=False, is_flag=True, help=(
     "Scan sources and create db migrations automatically. "
     "Supports autodiscovery."))
-@click.option('--auto-source', default=False, help=(
+@click.option('--auto-source', default=None, help=(
     "Set to python module path for changes autoscan (e.g. 'package.models'). "
     "Current directory will be recursively scanned by default."))
 @click.option('--database', default=None, help="Database connection")
